@@ -8,6 +8,9 @@ from shapely.wkb import loads
 from shapely.geometry import Point, Polygon, LineString, MultiLineString
 from shapely.ops import unary_union, polygonize
 import PySimpleGUI as sg
+import warnings
+warnings.filterwarnings("ignore")
+pd.options.mode.chained_assignment = None
 
 class latin_design:
     
@@ -18,6 +21,7 @@ class latin_design:
             self.point.crs = {'init': 'epsg:3857'}
         self.point.to_crs({'init': 'epsg:3857'})
         pd.options.mode.chained_assignment = None
+        warnings.filterwarnings("ignore")
         self.buffer_length = buffer_length
         xcords = self.point.geometry.x
         ycords = self.point.geometry.y
@@ -49,6 +53,7 @@ class select_geoms:
         self.gdf_path = gdf_path
         self.length = length
         pd.options.mode.chained_assignment = None
+        warnings.filterwarnings("ignore")
         if isinstance(self.gdf_path, str):
             try:
                 data = pd.concat([gpd.read_file(shp).to_crs({'init': 'epsg:3857'}) for shp in [i for i in glob.glob(f"{self.gdf_path}/*.shp")]]).pipe(gpd.GeoDataFrame)
@@ -144,6 +149,7 @@ class rotate_plot:
         self.aux_data = aux_data
         self.plot = plot
         self.attribute = attribute
+        warnings.filterwarnings("ignore")
         pd.options.mode.chained_assignment = None
         xmax, ymin, xmin, ymax= self.plot.total_bounds
         if isinstance(self.aux_data, gpd.GeoDataFrame):
@@ -182,6 +188,7 @@ class composite_union:
         self.buffer = buffer
         
         pd.options.mode.chained_assignment = None
+        warnings.filterwarnings("ignore")
         if data.crs == {'init': 'epsg: 4326'} and buffer == None:
             unary_data = gpd.GeoDataFrame(
                 geometry=gpd.GeoSeries(unary_union(data.geometry).intersection(
@@ -233,6 +240,7 @@ class check_topology:
         
         self.data = data
         pd.options.mode.chained_assignment = None
+        warnings.filterwarnings("ignore")
         if isinstance(data, str):
             gdf = gpd.read_file(self.data)
         elif isinstance(data, gpd.GeoDataFrame):
